-------------------------------------------------------------------------------
-- MrTrader 
--
-- Suite of tools for the avid crafter.
--
-- Send suggestions, comments, and bugs to user@zedonline.net
-------------------------------------------------------------------------------

MRTSkillContext = LibStub("Dewdrop-2.0");

local MenuSpacer = {
	text = "",
	isTitle = true,
}

function MRTSkillContext:DisplaySkillContext(frame, skillIndex)
	self:Open(frame, "children", function() MRTSkillContext:UpdateSkillContext(skillIndex); end);
end

function MRTSkillContext:DisplayFilterContext(frame)
	local filter = frame.filterRef;
	
	if( filter ) then
		self:Open(frame, "children", function() MRTSkillContext:UpdateFilterContext(filter); end);
	end
end

function MRTSkillContext:UpdateSkillContext(skillIndex)
	menu = {};
	local index = 100;
	local _, _, numAvailable, _, altVerb = GetTradeSkillInfo(skillIndex);
	
	if( not IsTradeSkillLinked() ) then
		menu[index] = {
			text = altVerb or CREATE,
			closeWhenClicked = true,
			func = function()
				if ( (not PartialPlayTime()) and (not NoPlayTime()) ) then
					DoTradeSkill(skillIndex, 1);
					MRTSkillInputBox:ClearFocus();
				end
			   end,
		}
		index = index + 1;
	
		if( not altVerb ) then
			menu[index] = {
				text = CREATE_ALL,
				closeWhenClicked = true,
				func = function()
					if ( (not PartialPlayTime()) and (not NoPlayTime()) ) then
						MRTSkillInputBox:SetNumber(numAvailable);
						DoTradeSkill(skillIndex, numAvailable);
						MRTSkillInputBox:ClearFocus();
					end
			   	end,
			}
			index = index + 1;
		end
	
		menu[index] = MenuSpacer;
		index = index + 1;
	end
	
	menu[index] = {
		text = MRTLoc["Favorite Groups"],
		textR = 1.0,
		textG = 0.8,
		textB = 0,
		isTitle = true,
	}
	index = index + 1;
	
	local skillSpellID = MrTrader:MatchPartialCraftSkillName(GetTradeSkillLine());
	local favorites = MrTrader:GetFavoritesForSkill(skillSpellID);
	
	if( favorites ) then
		for categoryName, categoryItems in pairs(favorites) do
			local skillSpell = MrTrader:GetSpellIDForRecipe(GetTradeSkillRecipeLink(skillIndex));
			local isIncluded = categoryItems[skillSpell] ~= nil;
			menu[index] = {
				text = categoryName,
				closeWhenClicked = false,
				checked = isIncluded,
				func = function ()
					if(not isIncluded) then
						MrTrader:AddFavoriteToSkill(skillSpellID, categoryName, skillSpell);
					else
						MrTrader:DelFavoriteFromSkill(skillSpellID, categoryName, skillSpell);
					end
					
					MRTSkillWindow:Update();
					isIncluded = not isIncluded;
					menu[index].checked = isIncluded;
				end,
			}
			index = index + 1;
		end
	end

	menu[index] = {
		text = MRTLoc["Add to New Favorite Group..."],
		closeWhenClicked = true,
		func = function ()
			MRTNewCategoryFrame.referenceSkill = skillIndex;
			MRTNewCategoryFrame:Show();
		end,
	}
	index = index + 1;
	
	menu[index] = MenuSpacer;
	index = index + 1;
	
	menu[index] = {
		text = MRTLoc["Close"],
		closeWhenClicked = true,
	}
	
	self:FeedTable(menu);
end

function MRTSkillContext:UpdateFilterContext(filter)
	menu = {};
	local index = 100;
	
	if( filter.filterType == "favorite" and filter.filterIndex == "__all" ) then
		menu[index] = {
			text = MRTLoc["New Favorite Group"],
			closeWhenClicked = true,
			func = function()
				MRTNewCategoryFrame.referenceSkill = nil;
				MRTNewCategoryFrame:Show();
			end,
		}
		index = index + 1;
	elseif( filter.filterType == "favorite" ) then
		menu[index] = {
			text = MRTLoc["Remove Favorite Group"],
			closeWhenClicked = true,
			func = function()
				MrTrader:DelFavoriteCategoryFromSkill(MrTrader:MatchPartialCraftSkillName(GetTradeSkillLine()), filter.filterIndex);
				
				MRTSkillWindow:PopulateFilterTree();
				MRTSkillWindow:Update();
			end,
		}
		index = index + 1;
	end
	
	if( index ~= 100 ) then
		menu[index] = MenuSpacer;
		index = index + 1;
	end
	
	menu[index] = {
		text = MRTLoc["Close"],
		closeWhenClicked = true,
	}
	
	self:FeedTable(menu);
end